﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace GameOfLife
{
    public partial class SettingsForm : Form
    {
        private void LoadSettings() {
            RegistryKey key = Registry.CurrentUser.OpenSubKey("SOFTWARE\\TheoryOfNekomata\\WindowsScreensavers\\GameOfLife");
            object retrievedGridSize = 3;
            object retrievedSpores = 0;
            object retrievedDensity = 50;
            object retrievedInterval = 250;

            if (key != null)
            {
                retrievedGridSize = key.GetValue("GridSizeIndex", 3);
                retrievedSpores = key.GetValue("Spores", 0);
                retrievedDensity = key.GetValue("DensityPercentage", 50);
                retrievedInterval = key.GetValue("IntervalMs", 250);
            }

            ctrlGridSize.SelectedIndex = (int) retrievedGridSize;
            ctrlSpores.Value = decimal.Parse(retrievedSpores.ToString());
            ctrlDensity.Value = (int)retrievedDensity;
            lblDensityValue.Text = string.Format("Current Value: {0}%", ctrlDensity.Value);
            ctrlInterval.Value = (int)retrievedInterval;
            lblIntervalValue.Text = string.Format("Current Value: {0}ms", ctrlInterval.Value);
        }

        private void SaveSettings() {
            RegistryKey key = Registry.CurrentUser.CreateSubKey("SOFTWARE\\TheoryOfNekomata\\WindowsScreensavers\\GameOfLife");
            key.SetValue("GridSizeIndex", ctrlGridSize.SelectedIndex);
            key.SetValue("Spores", int.Parse(ctrlSpores.Value.ToString()));
            key.SetValue("DensityPercentage", ctrlDensity.Value);
            key.SetValue("IntervalMs", ctrlInterval.Value);
        }

        public SettingsForm()
        {
            InitializeComponent();
            LoadSettings();
        }

        private void ctrlDensity_Scroll(object sender, EventArgs e)
        {
            lblDensityValue.Text = string.Format("Current Value: {0}%", (sender as TrackBar).Value);
        }

        private void ctrlInterval_Scroll(object sender, EventArgs e)
        {
            lblIntervalValue.Text = string.Format("Current Value: {0}ms", (sender as TrackBar).Value);
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            SaveSettings();
            Close();
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            Close();
        }
    }
}
